<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package B2B Company Account for Magento 2
 */

namespace Amasty\CompanyAccount\Observer;

use Amasty\CompanyAccount\Model\Credit\Order\Cancel as CancelOrder;
use Amasty\CompanyAccount\Model\CustomerDataProvider;
use Amasty\CompanyAccount\Model\Payment\ConfigProvider;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Exception\NoSuchEntityException;

class ReturnCompanyCredit implements ObserverInterface
{
    /**
     * @var CustomerDataProvider
     */
    private $customerDataProvider;

    /**
     * @var CancelOrder
     */
    private $cancelOrder;

    public function __construct(
        CustomerDataProvider $customerDataProvider,
        CancelOrder $cancelOrder
    ) {
        $this->customerDataProvider = $customerDataProvider;
        $this->cancelOrder = $cancelOrder;
    }

    public function execute(Observer $observer)
    {
        $order = $observer->getData('order');
        if (empty($order)) {
            return;
        }
        try {
            $company = $this->customerDataProvider->getCompanyByCustomerId((int)$order->getCustomerId());
            if ($company
                && $company->getCompanyId()
                && $order->getPayment()->getMethod() == ConfigProvider::METHOD_NAME
            ) {
                $this->cancelOrder->execute($order);
            }
        } catch (NoSuchEntityException $e) {
            null;// Do nothing
        }
    }
}
